==> hub_rest_client-0.1.1-py3-none-any.whl: hub_rest_client/api/default/get_dashboards_dashboard_id.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.dashboard import Dashboard
from ...types import UNSET, Response, Unset


def _get_kwargs(
    dashboard_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "name,data,permission,access,favorite,ordinal",
) -> Dict[str, Any]:
    url = "{}/dashboards/{dashboardId}".format(client.hub_base_url, dashboardId=dashboard_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Dashboard]:
    if response.status_code == 200:
        response_200 = Dashboard.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[Dashboard]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    dashboard_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "name,data,permission,access,favorite,ordinal",
) -> Response[Dashboard]:
    kwargs = _get_kwargs(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    dashboard_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "name,data,permission,access,favorite,ordinal",
) -> Optional[Dashboard]:
    """ """

    return sync_detailed(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    dashboard_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "name,data,permission,access,favorite,ordinal",
) -> Response[Dashboard]:
    kwargs = _get_kwargs(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    dashboard_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "name,data,permission,access,favorite,ordinal",
) -> Optional[Dashboard]:
    """ """

    return (
        await asyncio_detailed(
            dashboard_id=dashboard_id,
            client=client,
            fields=fields,
        )
    ).parsed

==> hub_rest_client-0.1.2-py3-none-any.whl: hub_rest_client/api/default/get_dashboards_dashboard_id.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models import dashboard as dashboard_m
from ...types import UNSET, Response, Unset


def _get_kwargs(
    dashboard_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "name,data,permission,access,favorite,ordinal",
) -> Dict[str, Any]:
    url = "{}/dashboards/{dashboardId}".format(client.hub_base_url, dashboardId=dashboard_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[dashboard_m.Dashboard]:
    if response.status_code == 200:
        response_200 = dashboard_m.Dashboard.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[dashboard_m.Dashboard]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    dashboard_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "name,data,permission,access,favorite,ordinal",
) -> Response[dashboard_m.Dashboard]:
    kwargs = _get_kwargs(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    dashboard_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "name,data,permission,access,favorite,ordinal",
) -> Optional[dashboard_m.Dashboard]:
    """ """

    return sync_detailed(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    dashboard_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "name,data,permission,access,favorite,ordinal",
) -> Response[dashboard_m.Dashboard]:
    kwargs = _get_kwargs(
        dashboard_id=dashboard_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    dashboard_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "name,data,permission,access,favorite,ordinal",
) -> Optional[dashboard_m.Dashboard]:
    """ """

    return (
        await asyncio_detailed(
            dashboard_id=dashboard_id,
            client=client,
            fields=fields,
        )
    ).parsed
